# -*- coding: UTF-8 -*-
# source http://www.becompta.be/modules/mydownloads/downloads-6-18.html

from __future__ import unicode_literals

PCMN = """
1 FONDS PROPRES, PROVISIONS POUR RISQUES ET CHARGES ET DETTES A PLUS D'UN AN
10 CAPITAL
100 Capital souscrit ou capital personnel
1000 Capital non amorti
1001 Capital amorti
101 Capital non appelé
109 Compte de l'exploitant
1090 Opérations courantes
1091 Impôts personnels
1092 Rémunérations et autres avantages
11 PRIMES D'EMISSION
12 PLUS-VALUES DE REEVALUATION
120 Plus-values de réévaluation sur immobilisations incorporelles
1200 Plus-values de réévaluation
1201 Reprises de réductions de valeur
121 Plus-values de réévaluation sur immobilisations corporelles
1210 Plus-values de réévaluation
1211 Reprises de réductions de valeur
122 Plus-values de réévaluation sur immobilisations financières
1220 Plus-values de réévaluation
1221 Reprises de réductions de valeur
123 Plus-values de réévaluation sur stocks
124 Reprises de réductions de valeur sur placements de trésorerie
13 RESERVES
130 Réserve légale
131 Réserves indisponibles
1310 Réserve pour actions propres
1311 Autres réserves indisponibles
132 Réserves immunisées
133 Réserves disponibles
1330 Réserve pour régularisation de dividendes
1331 Réserve pour renouvellement des immobilisations
1332 Réserve pour installations en faveur du personnel  1333 Réserves libres
14 BENEFICE REPORTE (ou PERTE REPORTEE)
15 SUBSIDES EN CAPITAL
150 Montants obtenus
151 Montants transférés aux résultats
16 PROVISIONS POUR RISQUES ET CHARGES
160 Provisions pour pensions et obligations similaires
161 Provisions pour charges fiscales
162 Provisions pour grosses réparations et gros entretiens
163 à 169 Provisions pour autres risques et charges
164 Provisions pour sûretés personnelles ou réelles constituées à l'appui de dettes et d'engagements de tiers
165 Provisions pour engagements relatifs à l'acquisition ou à la cession d'immobilisations
166 Provisions pour exécution de commandes passées ou reçues
167 Provisions pour positions et marchés à terme en devises ou positions et marchés à terme en marchandises
168 Provisions pour garanties techniques attachées aux ventes et prestations déjà effectuées par l'entreprise
169 Provisions pour autres risques et charges
1690 Pour litiges en cours
1691 Pour amendes, doubles droits, pénalités
1692 Pour propre assureur
1693 Pour risques inhérents aux opérations de crédits à moyen ou long terme
1695 Provision pour charge de liquidation
1696 Provision pour départ de personnel
1699 Pour risques divers 
17 DETTES A PLUS D'UN AN
170 Emprunts subordonnés
1700 Convertibles
1701 Non convertibles
171 Emprunts obligataires non subordonnés
1710 Convertibles
1711 Non convertibles
172 Dettes de location-financement et assimilés
1720 Dettes de location-financement de biens immobiliers
1721 Dettes de location-financement de biens mobiliers
1722 Dettes sur droits réels sur immeubles
173 Etablissements de crédit
1730 Dettes en compte
17300 Banque A
17301 Banque B
17302 Banque C
17303 Banque D
1731 Promesses
17310 Banque A
17311 Banque B
17312 Banque C
17313 Banque D
1732 Crédits d'acceptation
17320 Banque A
17321 Banque B
17322 Banque C
17323 Banque D
174 Autres emprunts
175 Dettes commerciales
1750 Fournisseurs : dettes en compte
17500 Entreprises apparentées
 175000 Entreprises liées
 175001 Entreprises avec lesquelles il existe un lien de participation
17501 Fournisseurs ordinaires
 175010 Fournisseurs belges
 175011 Fournisseurs C.E.E.
 175012 Fournisseurs importation
1751 Effets à payer
17510 Entreprises apparentées
 175100 Entreprises liées
 175101 Entreprises avec lesquelles il existe un lien de participation
17511 Fournisseurs ordinaires
 175110 Fournisseurs belges
 175111 Fournisseurs C.E.E.
 175112 Fournisseurs importation
176 Acomptes reçus sur commandes
178 Cautionnements reçus en numéraires
179 Dettes diverses
1790 Entreprises liées
1791 Autres entreprises avec lesquelles il existe un lien de participation
1792 Administrateurs, gérants, associés
1794 Rentes viagères capitalisées
1798 Dettes envers les coparticipants des associations momentanées et en participation
1799 Autres dettes diverses
18 COMPTES DE LIAISON DES ETABLISSEMENTS ET SUCCURSALES

2 FRAIS D'ETABLISSEMENT. ACTIFS IMMOBILISES ET CREANCES A PLUS D'UN AN
20 FRAIS D'ETABLISSEMENT
200 Frais de constitution et d'augmentation de capital
2000 Frais de constitution et d'augmentation de capital
2009 Amortissements sur frais de constitution et d'augmentation de capital
201 Frais d'émission d'emprunts et primes de remboursement
2010 Agios sur emprunts et frais d'émission d'emprunts
2019 Amortissements sur agios sur emprunts et frais d'émission d'emprunts
202 Autres frais d'établissement
2020 Autres frais d'établissement
2029 Amortissements sur autres frais d'établissement
203 Intérêts intercalaires
2030 Intérêts intercalaires
2039 Amortissements sur intérêts intercalaires
204 Frais de restructuration
2040 Coût des frais de restructuration
2049 Amortissements sur frais de restructuration
21 IMMOBILISATIONS INCORPORELLES
210 Frais de recherche et de développement
2100 Frais de recherche et de mise au point
2108 Plus-values actées sur frais de recherche et de mise au point
2109 Amortissements sur frais de recherche et de mise au point
211 Concessions, brevets, licences, savoir-faire, marques et droits similaires
2110 Concessions, brevets, licences, savoir-faire, marques, etc...
2118 Plus-values actées sur concessions, brevets, etc...
2119 Amortissements sur concessions, brevets, etc...
212 Goodwill
2120 Coût d'acquisition
2128 Plus-values actées
2129 Amortissements sur goodwill
213 Acomptes versés
22 TERRAINS ET CONSTRUCTIONS
220 Terrains
2200 Terrains
2201 Frais d'acquisition sur terrains
2208 Plus-values actées sur terrains
2209 Amortissements et réductions de valeur
22090 Amortissements sur frais d'acquisition
22091 Réductions de valeur sur terrains
221 Constructions
2210 Bâtiments industriels
2211 Bâtiments administratifs et commerciaux
2212 Autres bâtiments d'exploitation
2213 Voies de transport et ouvrages d'art
2215 Constructions sur sol d'autrui
2216 Frais d'acquisition sur constructions
2218 Plus-values actées
22180 Sur bâtiments industriels
22181 Sur bâtiments administratifs et commerciaux
22182 Sur autres bâtiments d'exploitation
22184 Sur voies de transport et ouvrages d'art
2219 Amortissements sur constructions
22190 Sur bâtiments industriels
22191 Sur bâtiments administratifs et commerciaux
22192 Sur autres bâtiments d'exploitation
22194 Sur voies de transport et ouvrages d'art
22195 Sur constructions sur sol d'autrui
22196 Sur frais d'acquisition sur constructions
222 Terrains bâtis
2220 Valeur d'acquisition
22200 Bâtiments industriels
22201 Bâtiments administratifs et commerciaux
22202 Autres bâtiments d'exploitation
22203 Voies de transport et ouvrages d'art
22204 Frais d'acquisition des terrains à bâtir
2228 Plus-values actées
22280 Sur bâtiments industriels	
22281 Sur bâtiments administratifs et commerciaux
22282 Sur autres bâtiments d'exploitation
22283 Sur voies de transport et ouvrages d'art
2229 Amortissements sur terrains bâtis
22290 Sur bâtiments industriels
22291 Sur bâtiments administratifs et commerciaux
22292 Sur autres bâtiments d'exploitation
22293 Sur voies de transport et ouvrages d'art
22294 Sur frais d'acquisition des terrains bâtis
223 Autres droits réels sur des immeubles
2230 Valeur d'acquisition
2238 Plus-values actées
2239 Amortissements
23 INSTALLATIONS, MACHINES ET OUTILLAGE
230 Installations
2300 Installations bâtiments industriels
2301 Installations bâtiments administratifs et commerciaux
2302 Installations bâtiments d'exploitation
2303 Installations voies de transport et ouvrages d'art
2300 Installation d'eau
2301 Installation d'électricité
2302 Installation de vapeur
2303 Installation de gaz
2304 Installation de chauffage
2305 Installation de conditionnement d'air
2306 Installation de chargement
231 Machines
2310 Division A
2311 Division B
2312 Division C
237 Outillage
2370 Division A
2371 Division B
2372 Division C
238 Plus-values actées
2380 Sur installations
2381 Sur machines
2382 Sur outillage
239 Amortissements
2390 Sur installations
2391 Sur machines
2392 Sur outillage
24 MOBILIER ET MATERIEL ROULANT
240 Mobilier
2400 Mobilier
24000 Mobilier des bâtiments industriels
24001 Mobilier des bâtiments administratifs et commerciaux
24002 Mobilier des autres bâtiments d'exploitation
24003 Mobilier oeuvres sociales
2401 Matériel de bureau et de service social
24010 Des bâtiments industriels
24011 Des bâtiments administratifs et commerciaux
24012 Des autres bâtiments d'exploitation
24013 Des oeuvres sociales
2408 Plus-values actées
24080 Plus-values actées sur mobilier
24081 Plus-values actées sur matériel de bureau et service social
2409 Amortissements
24090 Amortissements sur mobilier
24091 Amortissements sur matériel de bureau et service social
241 Matériel roulant
2410 Matériel automobile
24100 Voitures
24105 Camions
2411 Matériel ferroviaire
2412 Matériel fluvial
2413 Matériel naval
2414 Matériel aérien
2418 Plus-values sur matériel roulant
24180 Plus-values sur matériel automobile
24181 Idem sur matériel ferroviaire
24182 Idem sur matériel fluvial
24183 Idem sur matériel naval
24184 Idem sur matériel aérien
2419 Amortissements sur matériel roulant
24190 Amortissements sur matériel automobile
24191 Idem sur matériel ferroviaire
24192 Idem sur matériel fluvial
24193 Idem sur matériel naval
24194 Idem sur matériel aérien
25 IMMOBILISATION DETENUES EN LOCATION-FINANCEMENT ET DROITS SIMILAIRES
250 Terrains et constructions
2500 Terrains
2501 Constructions
2508 Plus-values sur emphytéose, leasing et droits similaires : terrains et constructions
2509 Amortissements et réductions de valeur sur terrains et constructions en leasing
251 Installations, machines et outillage
2510 Installations
2511 Machines
2512 Outillage
2518 Plus-values actées sur installations, machines et outillage pris en leasing
2519 Amortissements sur installations, machines et outillage pris en leasing
252 Mobilier et matériel roulant
2520 Mobilier
2521 Matériel roulant
2528 Plus-values actées sur mobilier et matériel roulant en leasing
2529 Amortissements sur mobilier et matériel roulant en leasing
26 AUTRES IMMOBILISATIONS CORPORELLES
260 Frais d'aménagements de locaux pris en location
261 Maison d'habitation
262 Réserve immobilière
263 Matériel d'emballage
264 Emballages récupérables
268 Plus-values actées sur autres immobilisations corporelles
269 Amortissements sur autres immobilisations corporelles
2690 Amortissements sur frais d'aménagement des locaux pris en location
2691 Amortissements sur maison d'habitation
2692 Amortissements sur réserve immobilière
2693 Amortissements sur matériel d'emballage
2694 Amortissements sur emballages récupérables
27 IMMOBILISATIONS CORPORELLES EN COURS ET ACOMPTES VERSES
270 Immobilisations en cours
2700 Constructions
2701 Installations, machines et outillage
2702 Mobilier et matériel roulant
2703 Autres immobilisations corporelles
271 Avances et acomptes versés sur immobilisations en cours
28 IMMOBILISATIONS FINANCIERES
280 Participations dans des entreprises liées
2800 Valeur d'acquisition (peut être subdivisé par participation)
2801 Montants non appelés (idem)
2808 Plus-values actées (idem)
2809 Réductions de valeurs actées (idem)
281 Créances sur des entreprises liées
2810 Créances en compte
2811 Effets à recevoir
2812 Titres à revenu fixes
2817 Créances douteuses
2819 Réductions de valeurs actées
282 Participations dans des entreprises avec lesquelles il existe un lien de participation
2820 Valeur d'acquisition (peut être subdivisé par participation)
2821 Montants non appelés (idem)
2828 Plus-values actées (idem)
2829 Réductions de valeurs actées (idem)
283 Créances sur des entreprises avec lesquelles il existe un lien de participation
2830 Créances en compte
2831 Effets à recevoir
2832 Titres à revenu fixe
2837 Créances douteuses
2839 Réductions de valeurs actées
284 Autres actions et parts
2840 Valeur d'acquisition
2841 Montants non appelés
2848 Plus-values actées
2849 Réductions de valeur actées
285 Autres créances
2850 Créances en compte
2851 Effets à recevoir
2852 Titres à revenu fixe
2857 Créances douteuses
2859 Réductions de valeur actées
288 Cautionnements versés en numéraires
2880 Téléphone, télefax, télex
2881 Gaz
2882 Eau
2883 Electricité
2887 Autres cautionnements versés en numéraires
29 CREANCES A PLUS D'UN AN
290 Créances commerciales
2900 Clients
29000 Créances en compte sur entreprises liées
29001 Sur entreprises avec lesquelles il existe un lien de participation
29002 Sur clients Belgique
29003 Sur clients C.E.E.
29004 Sur clients exportation hors C.E.E.
29005 Créances sur les coparticipants (associations momentanées)
2901 Effets à recevoir
29010 Sur entreprises liées
29011 Sur entreprises avec lesquelles il existe un lien de participation
29012 Sur clients Belgique
29013 Sur clients C.E.E.
29014 Sur clients exportation hors C.E.E.
2905 Retenues sur garanties
2906 Acomptes versés
2907 Créances douteuses (à ventiler comme clients 2900)
2909 Réductions de valeur actées (à ventiler comme clients 2900)
291 Autres créances
2910 Créances en compte
29100 Sur entreprises liées
29101 Sur entreprises avec lesquelles il existe un lien de participation
29102 Sur autres débiteurs
 291020 ....................
 291021 ....................
2911 Effets à recevoir
29110 Sur entreprises liées
29111 Sur entreprises avec lesquelles il existe un lien de participation
29112 Sur autres débiteurs
2912 Créances résultant de la cession d'immobilisations données en leasing
2917 Créances douteuses
2919 Réductions de valeur actées

3 STOCK ET COMMANDES EN COURS D'EXECUTION
30 APPROVISIONNEMENTS - MATIERES PREMIERES
300 Valeur d'acquisition
309 Réductions de valeur actées
31 APPROVISIONNEMENTS ET FOURNITURES
310 Valeur d'acquisition
3100 Matières d'approvisionnement
3101 Energie, charbon, coke, Mazout, essence, propane
3102 Produits d'entretien
3103 Fournitures diverses et petit outillage
3104 Imprimés et fournitures de bureau
3105 Fournitures de services sociaux
3106 Emballages commerciaux
31060 Emballages perdus
31061 Emballages récupérables
319 Réductions de valeur actées
32 EN COURS DE FABRICATION
320 Valeur d'acquisition
3200 Produits semi-ouvrés
3201 Produits en cours de fabrication
3202 Travaux en cours
3205 Déchets
3206 Rebuts
3209 Travaux en association momentanée
329 Réductions de valeur actées
33 PRODUITS FINIS
330 Valeur d'acquisition
3300 Produits finis
339 Réductions de valeur actées
34 MARCHANDISES
340 Valeur d'acquisition
3400 Groupe A
3401 Groupe B
3402 Groupe C
349 Réductions de valeur actées
35 IMMEUBLES DESTINES A LA VENTE
350 Valeur d'acquisition
3500 Immeuble A
3501 Immeuble B
3502 Immeuble C
351 Immeubles construits en vue de leur revente
3510 Immeuble A
3511 Immeuble B
3512 Immeuble C
359 Réductions de valeurs actées
36 ACOMPTES VERSES SUR ACHATS POUR STOCKS
360 Acomptes versés (à ventiler éventuellement par catégorie)
369 Réductions de valeur actées
37 COMMANDES EN COURS D'EXECUTION
370 Valeur d'acquisition
371 Bénéfice pris en compte
379 Réductions de valeur actées

4 CREANCES ET DETTES A UN AN AU PLUS
40 CREANCES COMMERCIALES
4000 Clients
4007 Rabais, remises, ristournes à accorder et autres notes de crédit
à établir
4008 Créances résultant de livraisons de biens (associations momentanées)
401 Effets à recevoir
4010 Effets à recevoir
4013 Effets à l'encaissement
4015 Effets à l'escompte
402 Clients, créances courantes, entreprises apparentées, administrateurs et gérants
4020 Entreprises liées
4021 Autres entreprises avec lesquelles il existe un lien de participation
4022 Administrateurs et gérants d'entreprise
403 Effets à recevoir sur entreprises apparentées et administrateurs et gérants
4030 Entreprises liées
4031 Autres entreprises avec lesquelles il existe un lien de participation
4032 Administrateurs et gérants de l'entreprise
404 Produits à recevoir (factures à établir)
405 Clients : retenues sur garanties
406 Acomptes versés
407 Créances douteuses
408 Compensation clients
409 Réductions de valeur actées
41 AUTRES CREANCES
410 Capital appelé, non versé
4100 Appels de fonds
4101 Actionnaires défaillants
411 T.V.A. à récupérer
4110 T.V.A. due
4111 T.V.A. déductible
4112 Compte courant administration T.V.A.
4118 Taxe d'égalisation due
412 Impôts et versements fiscaux à récupérer
4120 à 4124 Impôts belges sur le résultat
4125 à 4127 Autres impôts belges
4128 Impôts étrangers
414 Produits à recevoir
416 Créances diverses
4160 Associés (compte d'apport en société)
4161 Avances et prêts au personnel
4162 Compte courant des associés en S.P.R.L.
4163 Compte courant des administrateurs et gérants
4164 Créances sur sociétés apparentées
4166 Emballages et matériel à rendre
4167 Etat et établissements publics
41670 Subsides à recevoir
41671 Autres créances
4168 Rabais, ristournes, remises à obtenir et autres avoirs non encore reçus
417 Créances douteuses
418 Cautionnements versés en numéraires
419 Réductions de valeur actées
42 DETTES A PLUS D'UN AN ECHEANT DANS L'ANNEE
420 Emprunts subordonnés
4200 Convertibles
4201 Non convertibles
421 Emprunts obligataires non subordonnés
4210 Convertibles
4211 Non convertibles
422 Dettes de location-financement et assimilées
4220 Financement de biens immobiliers
4221 Financement de biens mobiliers
423 Etablissements de crédit
4230 Dettes en compte
4231 Promesses
4232 Crédits d'acceptation
424 Autres emprunts
425 Dettes commerciales
4250 Fournisseurs
4251 Effets à payer
426 Cautionnements reçus en numéraires
429 Dettes diverses
4290 Entreprises liées
4291 Entreprises avec lesquelles il existe un lien de participation
4292 Administrateurs, gérants, associés
4299 Autres dettes
43 DETTES FINANCIERES
430 Etablissements de crédit. Emprunts en compte à terme fixe
431 Etablissements de crédit. Promesses
432 Etablissements de crédit. Crédits d'acceptation
433 Etablissements de crédit. Dettes en compte courant
439 Autres emprunts
44 DETTES COMMERCIALES
440 Fournisseurs
4400 Entreprises apparentées
44000 Entreprises liées
44001 Entreprises avec lesquelles il existe un lien de participation
4401 Fournisseurs ordinaires
44010 Fournisseurs belges
44011 Fournisseurs CEE
44012 Fournisseurs importation
4402 Dettes envers les coparticipants (associations momentanées)
4403 Fournisseurs - retenues de garanties
441 Effets à payer
4410 Entreprises apparentées
44100 Entreprises liées
44101 Entreprises avec lesquelles il existe un lien de participation
4411 Fournisseurs ordinaires
44110 Fournisseurs belges
44111 Fournisseurs CEE
44112 Fournisseurs importation
444 Factures à recevoir
446 Acomptes reçus
448 Compensations fournisseurs
45 DETTES FISCALES, SALARIALES ET SOCIALES
450 Dettes fiscales estimées
4501 à 4504 Impôts sur le résultat
4505 à 4507 Autres impôts en Belgique
4508 Impôts à l'étranger
451 T.V.A. à payer
4510 T.V.A. due
4511 T.V.A. déductible
4512 Compte courant administration T.V.A.
4518 Taxe d'égalisation due
452 Impôts et taxes à payer
4520 à 4524 Autres impôts sur le résultat
4525 à 4527 Autres impôts et taxes en Belgique
 45250 Précompte immobilier
 45251 Impôts communaux à payer
 45252 Impôts provinciaux à payer
 45253 Autres impôts et taxes à payer
4528 Impôts et taxes à l'étranger
453 Précomptes retenus
4530 Précompte professionnel retenu sur rémunérations
4531 Précompte professionnel retenu sur tantièmes
4532 Précompte mobilier retenu sur dividendes attribués
4533 Précompte mobilier retenu sur intérêts payés
4538 Autres précomptes retenus
454 Office National de la Sécurité Sociale
4540 Arriérés
4541 1er trimestre
4542 2ème trimestre
4543 3ème trimestre
4544 4ème trimestre
455 Rémunérations
4550 Administrateurs, gérants et commissaires (non réviseurs)
4551 Direction
4552 Employés
4553 Ouvriers
456 Pécules de vacances
4560 Direction
4561 Employés
4562 Ouvriers
459 Autres dettes sociales
4590 Provision pour gratifications de fin d'année
4591 Départs de personnel
4592 Oppositions sur rémunérations
4593 Assurances relatives au personnel
45930 Assurance loi
45931 Assurance salaire garanti 
45932 Assurance groupe 
45933 Assurances individuelles
4594 Caisse d'assurances sociales pour travailleurs indépendants
4597 Dettes et provisions sociales diverses
46 ACOMPTES RECUS SUR COMMANDES
47 DETTES DECOULANT DE L'AFFECTATION DES RESULTATS
470 Dividendes et tantièmes d'exercices antérieurs
471 Dividendes de l'exercice
472 Tantièmes de l'exercice
473 Autres allocataires
48 DETTES DIVERSES
480 Obligations et coupons échus
481 Actionnaires - capital à rembourser
482 Participation du personnel à payer
483 Acomptes reçus d'autres tiers à moins d'un an
486 Emballages et matériel consignés
488 Cautionnements reçus en numéraires
489 Autres dettes diverses
49 COMPTES DE REGULARISATION ET COMPTES D'ATTENTE
490 Charges à reporter (à subdiviser par catégorie de charges)
491 Produits acquis
4910 Produits d'exploitation
49100 Ristournes, rabais à obtenir
49101 Commissions à obtenir
49102 Autres produits d'exploitation (redevances par exemple)
4911 Produits financiers
49110 Intérêts courus et non échus sur prêts et débits
49111 Autres produits financiers
492 Charges à imputer (à subdiviser par catégorie de charges)
493 Produits à reporter
4930 Produits d'exploitation à reporter
4931 Produits financiers à reporter
499 Comptes d'attente
4990 Compte d'attente
4991 Compte de répartition périodique des charges
4999 Transferts d'exercice

5 PLACEMENTS DE TRESORERIE ET DE VALEURS DISPONIBLES
50 ACTIONS PROPRES
51 ACTIONS ET PARTS
510 Valeur d'acquisition
511 Montants non appelés
519 Réductions de valeur actées
52 TITRES A REVENUS FIXES
520 Valeur d'acquisition
529 Réductions de valeur actées
53 DEPOTS A TERME
530 De plus d'un an
531 De plus d'un mois et à un an au plus
532 D'un mois au plus
539 Réductions de valeur actées
54 VALEURS ECHUES A L'ENCAISSEMENT
540 Chèques à encaisser
541 Coupons à encaisser
55 ETABLISSEMENTS DE DC.credit.
5500 Compte courant Banque 1
5501 Chèques émis Banque 1 
5509 Réductions de valeur actées Banque 1 
56 OFFICE DES CHEQUES POSTAUX
560 Compte courant
561 Chèques émis
57 CAISSES
5700 Caisse EUR
5710 Caisse EEK
578 Caisses - timbres ( 0 - fiscaux ; 1 - postaux)
58 VIREMENTS INTERNES

6 CHARGES
60 APPROVISIONNEMENTS ET MARCHANDISES
600 Achats de matières premières
601 Achats de fournitures
602 Achats de services, travaux et études
603 Sous-traitances générales
604 Achats de marchandises
605 Achats d'immeubles destinés à la revente
608 Remises, ristournes et rabais obtenus sur achats
609 Variations de stocks
6090 De matières premières
6091 De fournitures
6094 De marchandises
6095 D'immeubles destinés à la vente
61 SERVICES ET BIENS DIVERS
610 Loyers et charges locatives
6100 Loyers divers
6101 Charges locatives (assurances, frais de confort, ...)
611 Entretien et réparation (fournitures et prestations)
612 Fournitures faites à l'entreprise
6120 Eau, gaz, électricité, vapeur
61200 Eau
61201 Gaz
61202 Electricité
61203 Vapeur
6121 Téléphone et communication
61210 Téléphone
61211 Internet
6122 Livres, bibliothèque
6123 Imprimés et fournitures de bureau (si non comptabilisé au 601)
613 Rétributions de tiers
6130 Redevances et royalties
61300 Redevances pour brevets, licences, marques, accessoires
61301 Autres redevances (procédés de fabrication)
6131 Assurances non relatives au personnel
61310 Assurance incendie
61311 Assurance vol
61312 Assurance autos
61313 Assurance crédit
61314 Assurances frais généraux
6132 Divers
61320 Commissions aux tiers
61321 Honoraires d'avocats, d'experts, etc ...
61322 Cotisations aux groupements professionnels
61323 Dons, libéralités, ...
61324 Frais de contentieux
61325 Publications légales
6133 Transports et déplacements
61330 Transports de personnel
61331 Voyages, déplacements, représentations
6134 Personnel intérimaire
614 Annonces, publicité, propagande et documentation
6140 Annonces et insertions
6141 Catalogues et imprimés
6142 Echantillons
6143 Foires et expositions
6144 Primes
6145 Cadeaux à la clientèle
6146 Missions et réceptions
6147 Documentation
615 Sous-traitants
6150 Sous-traitants pour activités propres
6151 Sous-traitants d'associations momentanées (coparticipants)
6152 Quote-part bénéficiaire des coparticipants
61700 Personnel intérimaire et personnes mises à la disposition  de l'entreprise
61800 Rémunérations, primes pour assurances extralégales, pensions de retraite et de survie des administrateurs, gérants et associés actifs qui ne sont pas attribuées en vertu d'un contrat de travail
62 REMUNERATIONS, CHARGES SOCIALES ET PENSIONS
620 Rémunérations et avantages sociaux directs
6200 Administrateurs ou gérants
6201 Personnel de direction
6202 Employés
6203 Ouvriers
6204 Autres membres du personnel
621 Cotisations patronales d'assurances sociales
6210 Sur salaires
6211 Sur appointements et commissions
622 Primes patronales pour assurances extralégales
623 Autres frais de personnel
6230 Assurances du personnel
62300 Assurances loi, responsabilité civile, chemin du travail
62301 Assurance salaire garanti
62302 Assurances individuelles
6231 Charges sociales diverses
62310 Jours fériés payés
62311 Salaire hebdomadaire garanti
62312 Allocations familiales complémentaires
6232 Charges sociales des administrateurs, gérants et commissaires
62320 Allocations familiales complémentaires pour non salariés
62321 Lois sociales pour indépendants
62322 Divers
624 Pensions de retraite et de survie
6240 Administrateurs et gérants
6241 Personnel
625 Provision pour pécule de vacances
6250 Dotations
6251 Utilisations et reprises
63 AMORTISSEMENTS, REDUCTIONS DE VALEUR ET PROVISIONS POUR RISQUES ET CHARGES
630 Dotations aux amortissements et aux réductions de valeur sur immobilisations
6300 Dotations aux amortissements sur frais d'établissement
6301 Dotations aux amortissements sur immobilisations incorporelles
6302 Dotations aux amortissements sur immobilisations corporelles
6308 Dotations aux réductions de valeur sur immobilisations incorporelles
6309 Dotations aux réductions de valeur sur immobilisations corporelles
631 Réductions de valeur sur stocks
6310 Dotations
6311 Reprises
632 Réductions de valeur sur commandes en cours d'exécution
6320 Dotations
6321 Reprises
633 Réductions de valeur sur créances commerciales à plus d'un an
6330 Dotations
6331 Reprises
634 Réductions de valeur sur créances commerciales à un an au plus
6340 Dotations
6341 Reprises
635 Provisions pour pensions et obligations similaires
6350 Dotations
6351 Utilisations et reprises
636 Provisions pour grosses réparations et gros entretiens
6360 Dotations
6361 Utilisations et reprises
637 Provisions pour autres risques et charges
6370 Dotations 
6371 Utilisations et reprises
64 AUTRES CHARGES D'EXPLOITATION
640 Charges fiscales d'exploitation
6400 Taxes et impôts directs
64000 Taxes sur autos et camions
6401 Taxes et impôts indirects
64010 Timbres fiscaux pris en charge par la firme
64011 Droits d'enregistrement
64012 T.V.A. non déductible
6402 Impôts provinciaux et communaux
64020 Taxe sur la force motrice
64021 Taxe sur le personnel occupé
6403 Taxes diverses
641 Moins-values sur réalisations courantes d'immobilisations corporelles
642 Moins-values sur réalisations de créances commerciales
643 à 648 Charges d'exploitations diverses
649 Charges d'exploitation portées à l'actif au titre de restructuration
65 CHARGES FINANCIERES
650 Charges des dettes
6500 Intérêts, commissions et frais afférents aux dettes
6501 Amortissements des agios et frais d'émission d'emprunts
6502 Autres charges de dettes
6503 Intérêts intercalaires portés à l'actif
651 Réductions de valeur sur actifs circulants
6510 Dotations 
6511 Reprises
652 Moins-values sur réalisation d'actifs circulants
653 Charges d'escompte de créances
654 Différences de change
655 Ecarts de conversion des devises
656 Frais de banques, de chèques postaux
657 Commissions sur ouvertures de crédit, cautions, avals
658 Frais de vente des titres
66 CHARGES EXCEPTIONNELLES
660 Amortissements et réductions de valeur exceptionnels
6600 Sur frais d'établissement
6601 Sur immobilisations incorporelles
6602 Sur immobilisations corporelles
661 Réductions de valeur sur immobilisations financières
662 Provisions pour risques et charges exceptionnels
663 Moins-values sur réalisation d'actifs immobilisés
6630 Sur immobilisations incorporelles
6631 Sur immobilisations corporelles
6632 Sur immobilisations détenues en location-financement et droits similaires
6633 Sur immobilisations financières
6634 Sur immeubles acquis ou construits en vue de la revente
664 à 668 Autres charges exceptionnelles
664 Pénalités et amendes diverses
665 Différence de charge
669 Charges exceptionnelles transférées à l'actif en frais de restructuration
67 IMPOTS SUR LE RESULTAT
670 Impôts belges sur le résultat de l'exercice
6700 Impôts et précomptes dus ou versés
6701 Excédent de versements d'impôts et précomptes porté à l'actif
6702 Charges fiscales estimées
671 Impôts belges sur le résultat d'exercices antérieurs
6710 Suppléments d'impôts dus ou versés
6711 Suppléments d'impôts estimés
6712 Provisions fiscales constituées
672 Impôts étrangers sur le résultat de l'exercice
673 Impôts étrangers sur le résultat d'exercices antérieurs
68 TRANSFERTS AUX RESERVES IMMUNISEES
69 AFFECTATION DES RESULTATS
690 Perte reportée de l'exercice précédent
691 Dotation à la réserve légale
692 Dotation aux autres réserves
693 Bénéfice à reporter
694 Rémunération du capital
695 Administrateurs ou gérants
696 Autres allocataires

7 PRODUITS
70 CHIFFRE D'AFFAIRES
700 à 707 Ventes et prestations de services
700 Ventes de marchandises
7000 Ventes en Belgique
7001 Ventes dans les pays membres de la C.E.E.
7002 Ventes à l'exportation
701 Ventes de produits finis
7010 Ventes en Belgique
7011 Ventes dans les pays membres de la C.E.E.
7012 Ventes à l'exportation
702 Ventes de déchets et rebuts
7020 Ventes en Belgique
7021 Ventes dans les pays membres de la C.E.E.
7022 Ventes à l'exportation
703 Ventes d'emballages récupérables
704 Facturations des travaux en cours (associations momentanées)
705 Prestations de services
7050 Prestations de services en Belgique
7051 Prestations de services dans les pays membres de la C.E.E.
7052 Prestations de services en vue de l'exportation
706 Pénalités et dédits obtenus par l'entreprise
708 Remises, ristournes et rabais accordés
7080 Sur ventes de marchandises
7081 Sur ventes de produits finis
7082 Sur ventes de déchets et rebuts
7083 Sur prestations de services
7084 Mali sur travaux facturés aux associations momentanées
71 VARIATION DES STOCKS ET DES COMMANDES EN COURS D'EXECUTION
712 Des en cours de fabrication
713 Des produits finis
715 Des immeubles construits destinés à la vente
717 Des commandes en cours d'exécution
7170 Commandes en cours - Coût de revient
71700 Coût des commandes en cours d'exécution
71701 Coût des travaux en cours des associations momentanées
7171 Bénéfices portés en compte sur commandes en cours
71710 Sur commandes en cours d'exécution
71711 Sur travaux en cours des associations momentanées
72 PRODUCTION IMMOBILISEE
720 En frais d'établissement
721 En immobilisations incorporelles
722 En immobilisations corporelles
723 En immobilisations en cours
74 AUTRES PRODUITS D'EXPLOITATION
740 Subsides d'exploitation et montants compensatoires
741 Plus-values sur réalisations courantes d'immobilisations corporelles
742 Plus-values sur réalisations de créances commerciales
743 à 749 Produits d'exploitation divers
743 Produits de services exploités dans l'intérêt du personnel
744 Commissions et courtages
745 Redevances pour brevets et licences
746 Prestations de services (transports, études , etc...)
747 Revenus des immeubles affectés aux activités non professionnelles
748 Locations diverses à caractère professionnel
749 Produits divers
7490 Bonis sur reprises d'emballages consignés
7491 Bonis sur travaux en associations momentanées
75 PRODUITS FINANCIERS
750 Produits des immobilisations financières
7500 Revenus des actions
7501 Revenus des obligations
7502 Revenus des créances à plus d'un an
751 Produits des actifs circulants
752 Plus-values sur réalisations d'actifs circulants
753 Subsides en capital et en intérêts
754 Différences de change
755 Ecarts de conversion des devises
756 à 759 Produits financiers divers
756 Produits des autres créances
757 Escomptes obtenus
76 PRODUITS EXCEPTIONNELS
760 Reprises d'amortissements et de réductions de valeur
7600 Sur immobilisations incorporelles
7601 Sur immobilisations corporelles
761 Reprises de réductions de valeur sur immobilisations financières
762 Reprises de provisions pour risques et charges exceptionnelles
763 Plus-values sur réalisation d'actifs immobilisés
7630 Sur immobilisations incorporelles
7631 Sur immobilisations corporelles
7632 Sur immobilisations financières
764 Autres produits exceptionnels
77 REGULARISATIONS D'IMPOTS ET REPRISES DE PROVISIONS FISCALES
771 Impôts belges sur le résultat
7710 Régularisations d'impôts dus ou versés
7711 Régularisations d'impôts estimés
7712 Reprises de provisions fiscales
773 Impôts étrangers sur le résultat
79 AFFECTATION AUX RESULTATS
790 Bénéfice reporté de l'exercice précédent
791 Prélèvement sur le capital et les primes d'émission
792 Prélèvement sur les réserves
793 Perte à reporter
794 Intervention d'associés (ou du propriétaire) dans la perte
"""
